@@ -22,6 +22,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #define PARAMS(proto) proto
 
-double fstrcmp (const char *__s1, const char *__s2);
+double fstrcmp (const char *__s1, const char *__s2, double __minimum);
 
 #endif
